@@ -62,6 +62,8 @@ def main(argv):
     print("Copyright \N{COPYRIGHT SIGN} 2020 Stewartium ::: artify v{}\n".format(__version__))
     action = ''
     
+    path = os.path.abspath(os.getcwd()) 
+    
     # Variables - Deploy AWX
     global encoded_string 
     global url
@@ -95,9 +97,10 @@ def main(argv):
     global filename_gen
    
     try:
-        opts, args = getopt.getopt(argv, "a:b:c:d:h:f:m:n:u:p:r:g:t:w:", ["command=", "help", 
+        opts, args = getopt.getopt(argv, "a:b:c:d:h:f:m:n:u:p:r:g:t:w:", ["command=", "help=", 
                                                 "artifactname=", "repository=","groupid=", "directory=", "nexushost=",
                                                 "file=", "awxhost=",
+                                                "--format=",
                                                 "type=", "archtype=",
                                                 "message=", "branch=",
                                                 "debug"
@@ -105,7 +108,7 @@ def main(argv):
     except getopt.GetoptError:
         print('Invalid syntax')
         print('To get help, type syntax below: ')
-        print('python -m artify --help')
+        print('python -m artify --help=')
         return sys.exit(2)
     
     for opt, arg in opts:
@@ -166,6 +169,7 @@ def main(argv):
                 print('python -m artify --help deploy       Help on how to deploy to AWX host')
                 print('python -m artify --help syncrepo     Help on how to commit and push code to repository')
                 print('python -m artify --help deltav      Help on how to change version number')
+                return sys.exit(0)
         elif opt == "--debug":
             debug = 1
         elif opt in ("-c", "--command"):
@@ -187,8 +191,13 @@ def main(argv):
                     print("Please specify nexus repository format e.g npm, maven, raw, nuget")
                     return sys.exit(2) 
             elif action == 'deploy':
-                with open(arg, "rb") as manifest_file:
-                    encoded_string = base64.b64encode(manifest_file.read())
+                file_path = os.path.join(path, arg)
+                if os.path.exists(file_path):
+                    with open(arg, "rb") as manifest_file:
+                        encoded_string = base64.b64encode(manifest_file.read())
+                else:
+                    print("ERROR: File {} does not exist".format(arg))
+                    return sys.exit(2)
             elif action == 'create':
                 # Generate file START
                 filename_gen = arg
@@ -288,6 +297,8 @@ def main(argv):
         
         ## Commit-push changes repository END
          
+    if debug == 1:
+        print("Action entered: ", action)
     if action == 'nexus':
         nexus.setup_variables()
         print("Nexus Format entered: ", nexus_format)
