@@ -278,10 +278,13 @@ def change_manifest(v, dv):
     
     global path
     file_path = __main__.os.path.join(path, 'manifest.yml')
-    
-    old_version = "version: {}".format(v)
-    new_version = "version: {}".format(dv)
-    replace_version(file_path, old_version, new_version)
+    if __main__.os.path.exists(file_path):
+        old_version = "version: {}".format(v)
+        new_version = "version: {}".format(dv)
+        replace_version(file_path, old_version, new_version)
+        print("INFO: manifest.yml updated successfully.")
+    else:
+        print("INFO: No manifest.yml file exist")
     
     
     ## check if manifest.yml exist
